@@ -13,9 +13,9 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5594 $
-## |  Last changed: $Date: 2021-11-26 15:24:35 +0100 (Fr, 26 Nov 2021) $
-## |  Last changed by: $Author: pahlke $
+## |  File version: $Revision: 5747 $
+## |  Last changed: $Date: 2022-01-24 12:14:58 +0100 (Mo, 24 Jan 2022) $
+## |  Last changed by: $Author: wassmer $
 ## |
 
 # @title
@@ -69,7 +69,9 @@
     .warnInCaseOfUnknownArguments(
         functionName = ".getAnalysisResultsRatesInverseNormalMultiArm",
         ignore = c(.getDesignArgumentsToIgnoreAtUnknownArgumentCheck(
-            design, powerCalculationEnabled = TRUE), "stage"), ...
+            design,
+            powerCalculationEnabled = TRUE
+        ), "stage"), ...
     )
 
     results <- AnalysisResultsMultiArmInverseNormal(design = design, dataInput = dataInput)
@@ -102,7 +104,9 @@
     .warnInCaseOfUnknownArguments(
         functionName = ".getAnalysisResultsRatesFisherMultiArm",
         ignore = c(.getDesignArgumentsToIgnoreAtUnknownArgumentCheck(
-            design, powerCalculationEnabled = TRUE), "stage"), ...
+            design,
+            powerCalculationEnabled = TRUE
+        ), "stage"), ...
     )
 
     results <- AnalysisResultsMultiArmFisher(design = design, dataInput = dataInput)
@@ -132,7 +136,9 @@
     .warnInCaseOfUnknownArguments(
         functionName = ".getAnalysisResultsRatesConditionalDunnettMultiArm",
         ignore = c(.getDesignArgumentsToIgnoreAtUnknownArgumentCheck(
-            design, powerCalculationEnabled = TRUE), "stage"), ...
+            design,
+            powerCalculationEnabled = TRUE
+        ), "stage"), ...
     )
 
     results <- AnalysisResultsConditionalDunnett(design = design, dataInput = dataInput)
@@ -266,8 +272,10 @@
     results$repeatedConfidenceIntervalUpperBounds <- results$repeatedConfidenceIntervalLowerBounds
     for (k in 1:design$kMax) {
         for (treatmentArm in 1:gMax) {
-            results$repeatedConfidenceIntervalLowerBounds[treatmentArm, k] <- repeatedConfidenceIntervals[treatmentArm, 1, k]
-            results$repeatedConfidenceIntervalUpperBounds[treatmentArm, k] <- repeatedConfidenceIntervals[treatmentArm, 2, k]
+            results$repeatedConfidenceIntervalLowerBounds[treatmentArm, k] <-
+                repeatedConfidenceIntervals[treatmentArm, 1, k]
+            results$repeatedConfidenceIntervalUpperBounds[treatmentArm, k] <-
+                repeatedConfidenceIntervals[treatmentArm, 2, k]
         }
     }
     results$.setParameterType("repeatedConfidenceIntervalLowerBounds", C_PARAM_GENERATED)
@@ -314,7 +322,8 @@
         }
     }
     intersectionTest <- .getCorrectedIntersectionTestMultiArmIfNecessary(
-        design, intersectionTest, userFunctionCallEnabled)
+        design, intersectionTest, userFunctionCallEnabled
+    )
     .assertIsValidIntersectionTestMultiArm(design, intersectionTest)
 
     if (intersectionTest == "Dunnett" && !normalApproximation) {
@@ -353,13 +362,13 @@
         piControl[1, k] <- dataInput$getOverallEvents(stage = k, group = gMax + 1) /
             dataInput$getOverallSampleSizes(stage = k, group = gMax + 1)
 
-        for (g in 1:gMax) {
-            piTreatments[g, k] <- dataInput$getOverallEvents(stage = k, group = g) /
-                dataInput$getOverallSampleSizes(stage = k, group = g)
+        for (treatmentArm in 1:gMax) {
+            piTreatments[treatmentArm, k] <- dataInput$getOverallEvents(stage = k, group = treatmentArm) /
+                dataInput$getOverallSampleSizes(stage = k, group = treatmentArm)
 
-            actEv <- dataInput$getEvents(stage = k, group = g)
+            actEv <- dataInput$getEvents(stage = k, group = treatmentArm)
             ctrEv <- dataInput$getEvents(stage = k, group = gMax + 1)
-            actN <- dataInput$getSampleSize(stage = k, group = g)
+            actN <- dataInput$getSampleSize(stage = k, group = treatmentArm)
             ctrN <- dataInput$getSampleSize(stage = k, group = gMax + 1)
 
             if (normalApproximation) {
@@ -367,10 +376,10 @@
                     if (!is.na(actEv)) {
                         if ((actEv + ctrEv == 0) ||
                                 (actEv + ctrEv == actN + ctrN)) {
-                            testStatistics[g, k] <- 0
+                            testStatistics[treatmentArm, k] <- 0
                         } else {
                             rateH0 <- (actEv + ctrEv) / (actN + ctrN)
-                            testStatistics[g, k] <- (actEv / actN - ctrEv / ctrN - thetaH0) /
+                            testStatistics[treatmentArm, k] <- (actEv / actN - ctrEv / ctrN - thetaH0) /
                                 sqrt(rateH0 * (1 - rateH0) * (1 / actN + 1 / ctrN))
                         }
                     }
@@ -380,15 +389,15 @@
                         rate2 = ctrEv / ctrN, theta = thetaH0, allocation = actN / ctrN, method = "diff"
                     )
 
-                    testStatistics[g, k] <-
+                    testStatistics[treatmentArm, k] <-
                         (actEv / actN - ctrEv / ctrN - thetaH0) /
                             sqrt(y$ml1 * (1 - y$ml1) / actN + y$ml2 * (1 - y$ml2) / ctrN)
                 }
 
                 if (directionUpper) {
-                    separatePValues[g, k] <- 1 - stats::pnorm(testStatistics[g, k])
+                    separatePValues[treatmentArm, k] <- 1 - stats::pnorm(testStatistics[treatmentArm, k])
                 } else {
-                    separatePValues[g, k] <- stats::pnorm(testStatistics[g, k])
+                    separatePValues[treatmentArm, k] <- stats::pnorm(testStatistics[treatmentArm, k])
                 }
             } else {
                 if (thetaH0 != 0) {
@@ -399,14 +408,14 @@
                 }
 
                 if (directionUpper) {
-                    separatePValues[g, k] <- stats::phyper(actEv - 1,
+                    separatePValues[treatmentArm, k] <- stats::phyper(actEv - 1,
                         actEv + ctrEv,
                         actN + ctrN - actEv - ctrEv,
                         actN,
                         lower.tail = FALSE
                     )
                 } else {
-                    separatePValues[g, k] <- stats::phyper(actEv,
+                    separatePValues[treatmentArm, k] <- stats::phyper(actEv,
                         actEv + ctrEv,
                         actN + ctrN - actEv - ctrEv,
                         actN,
@@ -421,9 +430,9 @@
             }
 
             # overall test statistics
-            actEv <- dataInput$getOverallEvents(stage = k, group = g)
+            actEv <- dataInput$getOverallEvents(stage = k, group = treatmentArm)
             ctrEv <- dataInput$getOverallEvents(stage = k, group = gMax + 1)
-            actN <- dataInput$getOverallSampleSize(stage = k, group = g)
+            actN <- dataInput$getOverallSampleSize(stage = k, group = treatmentArm)
             ctrN <- dataInput$getOverallSampleSize(stage = k, group = gMax + 1)
 
             if (normalApproximation) {
@@ -431,10 +440,10 @@
                     if (!is.na(actEv)) {
                         if ((actEv + ctrEv == 0) ||
                                 (actEv + ctrEv == actN + ctrN)) {
-                            overallTestStatistics[g, k] <- 0
+                            overallTestStatistics[treatmentArm, k] <- 0
                         } else {
                             overallRateH0 <- (actEv + ctrEv) / (actN + ctrN)
-                            overallTestStatistics[g, k] <- (actEv / actN - ctrEv / ctrN - thetaH0) /
+                            overallTestStatistics[treatmentArm, k] <- (actEv / actN - ctrEv / ctrN - thetaH0) /
                                 sqrt(overallRateH0 * (1 - overallRateH0) * (1 / actN + 1 / ctrN))
                         }
                     }
@@ -444,15 +453,15 @@
                         theta = thetaH0, allocation = actN / ctrN, method = "diff"
                     )
 
-                    overallTestStatistics[g, k] <-
+                    overallTestStatistics[treatmentArm, k] <-
                         (actEv / actN - ctrEv / ctrN - thetaH0) /
                             sqrt(y$ml1 * (1 - y$ml1) / actN + y$ml2 * (1 - y$ml2) / ctrN)
                 }
 
                 if (directionUpper) {
-                    overallPValues[g, k] <- 1 - stats::pnorm(overallTestStatistics[g, k])
+                    overallPValues[treatmentArm, k] <- 1 - stats::pnorm(overallTestStatistics[treatmentArm, k])
                 } else {
-                    overallPValues[g, k] <- stats::pnorm(overallTestStatistics[g, k])
+                    overallPValues[treatmentArm, k] <- stats::pnorm(overallTestStatistics[treatmentArm, k])
                 }
             } else {
                 if (thetaH0 != 0) {
@@ -463,21 +472,21 @@
                 }
 
                 if (directionUpper) {
-                    overallPValues[g, k] <- stats::phyper(actEv - 1,
+                    overallPValues[treatmentArm, k] <- stats::phyper(actEv - 1,
                         actEv + ctrEv,
                         actN + ctrN - actEv - ctrEv,
                         actN,
                         lower.tail = FALSE
                     )
                 } else {
-                    overallPValues[g, k] <- stats::phyper(actEv,
+                    overallPValues[treatmentArm, k] <- stats::phyper(actEv,
                         actEv + ctrEv,
                         actN + ctrN - actEv - ctrEv,
                         actN,
                         lower.tail = TRUE
                     )
                 }
-                
+
                 if (directionUpper) {
                     overallTestStatistics <- .getOneMinusQNorm(overallPValues)
                 } else {
@@ -486,7 +495,7 @@
             }
         }
     }
-    
+
     stageResults$overallPiControl <- piControl
     stageResults$overallPiTreatments <- piTreatments
     stageResults$overallTestStatistics <- overallTestStatistics
@@ -495,8 +504,8 @@
     stageResults$separatePValues <- separatePValues
 
     effectSizes <- matrix(numeric(0), ncol = ncol(piControl))
-    for (g in 1:gMax) {
-        effectSizes <- rbind(effectSizes, piTreatments[g, ] - piControl)
+    for (treatmentArm in 1:gMax) {
+        effectSizes <- rbind(effectSizes, piTreatments[treatmentArm, ] - piControl)
     }
     stageResults$effectSizes <- effectSizes
     stageResults$.setParameterType("effectSizes", C_PARAM_GENERATED)
@@ -529,35 +538,35 @@
             sqrt(t(sampleSizesSelected / (sampleSizesSelected +
                 dataInput$getSampleSize(k, gMax + 1))))
         diag(sigma) <- 1
-        for (g in 1:gMax) {
+        for (treatmentArm in 1:gMax) {
             if ((intersectionTest == "Bonferroni") || (intersectionTest == "Simes")) {
                 if (.isTrialDesignGroupSequential(design)) {
-                    overallPValues[g, k] <- min(1, overallPValues[g, k] * selected)
+                    overallPValues[treatmentArm, k] <- min(1, overallPValues[treatmentArm, k] * selected)
                 } else {
-                    singleStepAdjustedPValues[g, k] <- min(1, separatePValues[g, k] * selected)
+                    singleStepAdjustedPValues[treatmentArm, k] <- min(1, separatePValues[treatmentArm, k] * selected)
                 }
             } else if (intersectionTest == "Sidak") {
                 if (.isTrialDesignGroupSequential(design)) {
-                    overallPValues[g, k] <- 1 - (1 - overallPValues[g, k])^selected
+                    overallPValues[treatmentArm, k] <- 1 - (1 - overallPValues[treatmentArm, k])^selected
                 } else {
-                    singleStepAdjustedPValues[g, k] <- 1 - (1 - separatePValues[g, k])^selected
+                    singleStepAdjustedPValues[treatmentArm, k] <- 1 - (1 - separatePValues[treatmentArm, k])^selected
                 }
             } else if (intersectionTest == "Dunnett") {
-                if (!is.na(testStatistics[g, k])) {
+                if (!is.na(testStatistics[treatmentArm, k])) {
                     df <- NA_real_
-                    singleStepAdjustedPValues[g, k] <- 1 - .getMultivariateDistribution(
+                    singleStepAdjustedPValues[treatmentArm, k] <- 1 - .getMultivariateDistribution(
                         type = "normal",
-                        upper = ifelse(directionUpper, testStatistics[g, k], -testStatistics[g, k]),
+                        upper = ifelse(directionUpper, testStatistics[treatmentArm, k], -testStatistics[treatmentArm, k]),
                         sigma = sigma, df = df
                     )
                 }
             }
             if (.isTrialDesignInverseNormal(design)) {
-                combInverseNormal[g, k] <- (weightsInverseNormal[1:k] %*%
-                    .getOneMinusQNorm(singleStepAdjustedPValues[g, 1:k])) /
+                combInverseNormal[treatmentArm, k] <- (weightsInverseNormal[1:k] %*%
+                    .getOneMinusQNorm(singleStepAdjustedPValues[treatmentArm, 1:k])) /
                     sqrt(sum(weightsInverseNormal[1:k]^2))
             } else if (.isTrialDesignFisher(design)) {
-                combFisher[g, k] <- prod(singleStepAdjustedPValues[g, 1:k]^weightsFisher[1:k])
+                combFisher[treatmentArm, k] <- prod(singleStepAdjustedPValues[treatmentArm, 1:k]^weightsFisher[1:k])
             }
         }
     }
@@ -698,6 +707,8 @@
             bounds <- design$futilityBounds
             border <- C_FUTILITY_BOUNDS_DEFAULT
             criticalValues <- design$criticalValues
+            criticalValues[is.infinite(criticalValues) & criticalValues > 0] <- C_QNORM_MAXIMUM
+            criticalValues[is.infinite(criticalValues) & criticalValues < 0] <- C_QNORM_MINIMUM
             conditionFunction <- .isFirstValueGreaterThanSecondValue
         }
 
@@ -707,23 +718,23 @@
         stages <- (1:stage)
         for (k in stages) {
             startTime <- Sys.time()
-            for (g in 1:gMax) {
-                if (!is.na(stageResults$testStatistics[g, k])) {
+            for (treatmentArm in 1:gMax) {
+				if (!is.na(stageResults$testStatistics[treatmentArm, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
                     thetaLow <- -1 + tolerance
                     thetaUp <- 1 - tolerance
                     # finding upper and lower RCI limits through root function
-                    repeatedConfidenceIntervals[g, 1, k] <- .getRootThetaRatesMultiArm(
+                    repeatedConfidenceIntervals[treatmentArm, 1, k] <- .getRootThetaRatesMultiArm(
                         design = design,
-                        dataInput = dataInput, treatmentArm = g, stage = k, directionUpper = TRUE,
+                        dataInput = dataInput, treatmentArm = treatmentArm, stage = k, directionUpper = TRUE,
                         normalApproximation = normalApproximation,
                         thetaLow = thetaLow, thetaUp = thetaUp,
                         intersectionTest = intersectionTest, firstParameterName = firstParameterName,
                         secondValue = criticalValues[k], tolerance = tolerance
                     )
 
-                    repeatedConfidenceIntervals[g, 2, k] <- .getRootThetaRatesMultiArm(
+                    repeatedConfidenceIntervals[treatmentArm, 2, k] <- .getRootThetaRatesMultiArm(
                         design = design,
-                        dataInput = dataInput, treatmentArm = g, stage = k, directionUpper = FALSE,
+                        dataInput = dataInput, treatmentArm = treatmentArm, stage = k, directionUpper = FALSE,
                         normalApproximation = normalApproximation,
                         thetaLow = thetaLow, thetaUp = thetaUp,
                         intersectionTest = intersectionTest, firstParameterName = firstParameterName,
@@ -738,7 +749,7 @@
 
                         futilityCorr[k] <- .getRootThetaRatesMultiArm(
                             design = design, dataInput = dataInput,
-                            treatmentArm = g, stage = k - 1, directionUpper = directionUpper,
+                            treatmentArm = treatmentArm, stage = k - 1, directionUpper = directionUpper,
                             normalApproximation = normalApproximation,
                             thetaLow = thetaLow, thetaUp = thetaUp,
                             intersectionTest = intersectionTest, firstParameterName = parameterName,
@@ -746,22 +757,22 @@
                         )
 
                         if (directionUpper) {
-                            repeatedConfidenceIntervals[g, 1, k] <- min(
+                            repeatedConfidenceIntervals[treatmentArm, 1, k] <- min(
                                 min(futilityCorr[2:k]),
-                                repeatedConfidenceIntervals[g, 1, k]
+                                repeatedConfidenceIntervals[treatmentArm, 1, k]
                             )
                         } else {
-                            repeatedConfidenceIntervals[g, 2, k] <- max(
+                            repeatedConfidenceIntervals[treatmentArm, 2, k] <- max(
                                 max(futilityCorr[2:k]),
-                                repeatedConfidenceIntervals[g, 2, k]
+                                repeatedConfidenceIntervals[treatmentArm, 2, k]
                             )
                         }
                     }
 
-                    if (!is.na(repeatedConfidenceIntervals[g, 1, k]) &&
-                            !is.na(repeatedConfidenceIntervals[g, 2, k]) &&
-                            repeatedConfidenceIntervals[g, 1, k] > repeatedConfidenceIntervals[g, 2, k]) {
-                        repeatedConfidenceIntervals[g, , k] <- rep(NA_real_, 2)
+                    if (!is.na(repeatedConfidenceIntervals[treatmentArm, 1, k]) &&
+                            !is.na(repeatedConfidenceIntervals[treatmentArm, 2, k]) &&
+                            repeatedConfidenceIntervals[treatmentArm, 1, k] > repeatedConfidenceIntervals[treatmentArm, 2, k]) {
+                        repeatedConfidenceIntervals[treatmentArm, , k] <- rep(NA_real_, 2)
                     }
                 }
             }
@@ -818,7 +829,9 @@
         functionName =
             ".getRepeatedConfidenceIntervalsRatesMultiArmFisher",
         ignore = c(.getDesignArgumentsToIgnoreAtUnknownArgumentCheck(
-            design, powerCalculationEnabled = TRUE), "stage"), ...
+            design,
+            powerCalculationEnabled = TRUE
+        ), "stage"), ...
     )
 
     return(.getRepeatedConfidenceIntervalsRatesMultiArmAll(
@@ -887,8 +900,10 @@
     piTreatmentsH1 <- .getOptionalArgument("piTreatmentsH1", ...)
     if (!is.null(piTreatmentsH1) && !is.na(piTreatmentsH1)) {
         if (!is.na(piTreatments)) {
-            warning(sQuote("piTreatments"), " will be ignored because ", 
-                sQuote("piTreatmentsH1"), " is defined", call. = FALSE)
+            warning(sQuote("piTreatments"), " will be ignored because ",
+                sQuote("piTreatmentsH1"), " is defined",
+                call. = FALSE
+            )
         }
         piTreatments <- piTreatmentsH1
     }
@@ -896,8 +911,10 @@
     piControlH1 <- .getOptionalArgument("piControlH1", ...)
     if (!is.null(piControlH1) && !is.na(piControlH1)) {
         if (!is.na(piControl)) {
-            warning(sQuote("piControl"), " will be ignored because ", 
-                sQuote("piControlH1"), " is defined", call. = FALSE)
+            warning(sQuote("piControl"), " will be ignored because ",
+                sQuote("piControlH1"), " is defined",
+                call. = FALSE
+            )
         }
         piControl <- piControlH1
     }
@@ -1012,7 +1029,7 @@
         sqrt(piTreatments * (1 - piTreatments) + allocationRatioPlanned * piControl * (1 - piControl))) *
         (1 + allocationRatioPlanned) / sqrt(allocationRatioPlanned * sum(nPlanned[(stage + 1):kMax]))
     adjustment[condError < 1e-12] <- 0
-        
+
     results$.setParameterType("piControl", C_PARAM_DEFAULT_VALUE)
     if (length(piTreatments) == 1) {
         piTreatments <- rep(piTreatments, gMax)
@@ -1034,16 +1051,16 @@
     ctr <- .performClosedCombinationTest(stageResults = stageResults)
     criticalValues <- design$criticalValues
 
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
+    for (treatmentArm in 1:gMax) {
+        if (!is.na(ctr$separatePValues[treatmentArm, stage])) {
             # shifted decision region for use in getGroupSeqProbs
             # Inverse Normal Method
             shiftedDecisionRegionUpper <- criticalValues[(stage + 1):kMax] *
                 sqrt(sum(weights[1:stage]^2) + cumsum(weights[(stage + 1):kMax]^2)) /
                 sqrt(cumsum(weights[(stage + 1):kMax]^2)) -
-                min(ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage], na.rm = TRUE) *
+                min(ctr$overallAdjustedTestStatistics[ctr$indices[, treatmentArm] == 1, stage], na.rm = TRUE) *
                     sqrt(sum(weights[1:stage]^2)) /
-                    sqrt(cumsum(weights[(stage + 1):kMax]^2)) - standardizedEffect[g] *
+                    sqrt(cumsum(weights[(stage + 1):kMax]^2)) - standardizedEffect[treatmentArm] *
                     cumsum(sqrt(nPlanned[(stage + 1):kMax]) * weights[(stage + 1):kMax]) /
                     sqrt(cumsum(weights[(stage + 1):kMax]^2))
             if (stage == kMax - 1) {
@@ -1052,9 +1069,9 @@
                 shiftedFutilityBounds <- design$futilityBounds[(stage + 1):(kMax - 1)] *
                     sqrt(sum(weights[1:stage]^2) + cumsum(weights[(stage + 1):(kMax - 1)]^2)) /
                     sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) -
-                    min(ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage], na.rm = TRUE) *
+                    min(ctr$overallAdjustedTestStatistics[ctr$indices[, treatmentArm] == 1, stage], na.rm = TRUE) *
                         sqrt(sum(weights[1:stage]^2)) /
-                        sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) - standardizedEffect[g] *
+                        sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2)) - standardizedEffect[treatmentArm] *
                         cumsum(sqrt(nPlanned[(stage + 1):(kMax - 1)]) * weights[(stage + 1):(kMax - 1)]) /
                         sqrt(cumsum(weights[(stage + 1):(kMax - 1)]^2))
             }
@@ -1073,7 +1090,7 @@
                 informationRates = scaledInformation
             )
 
-            results$conditionalPower[g, (stage + 1):kMax] <- cumsum(probs[3, ] - probs[2, ])
+            results$conditionalPower[treatmentArm, (stage + 1):kMax] <- cumsum(probs[3, ] - probs[2, ])
         }
     }
     nPlanned <- (1 + allocationRatioPlanned)^2 / allocationRatioPlanned * nPlanned
@@ -1147,13 +1164,13 @@
     nPlanned <- allocationRatioPlanned / (1 + allocationRatioPlanned)^2 * nPlanned
 
     ctr <- .performClosedCombinationTest(stageResults = stageResults)
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
+    for (treatmentArm in 1:gMax) {
+        if (!is.na(ctr$separatePValues[treatmentArm, stage])) {
             if (gMax == 1) {
-                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, g] == 1, ][1:stage]
+                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, treatmentArm] == 1, ][1:stage]
             } else {
-                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, g] == 1, ][which.max(
-                    ctr$overallAdjustedTestStatistics[ctr$indices[, g] == 1, stage]
+                pValues <- ctr$adjustedStageWisePValues[ctr$indices[, treatmentArm] == 1, ][which.max(
+                    ctr$overallAdjustedTestStatistics[ctr$indices[, treatmentArm] == 1, stage]
                 ), 1:stage]
             }
             if (stage < kMax - 1) {
@@ -1163,11 +1180,11 @@
                         reject <- reject + .getRejectValueConditionalPowerFisher(
                             kMax = kMax, alpha0Vec = design$alpha0Vec,
                             criticalValues = criticalValues, weightsFisher = weightsFisher,
-                            pValues = pValues, currentKMax = k, thetaH1 = standardizedEffect[g],
+                            pValues = pValues, currentKMax = k, thetaH1 = standardizedEffect[treatmentArm],
                             stage = stage, nPlanned = nPlanned
                         )
                     }
-                    results$conditionalPower[g, k] <- reject / iterations
+                    results$conditionalPower[treatmentArm, k] <- reject / iterations
                 }
                 results$simulated <- TRUE
                 results$.setParameterType("simulated", C_PARAM_GENERATED)
@@ -1177,10 +1194,10 @@
 
                 if (result <= 0 || result >= 1) {
                     warning("Calculation not possible: could not calculate conditional power for stage ", kMax, call. = FALSE)
-                    results$conditionalPower[g, kMax] <- NA_real_
+                    results$conditionalPower[treatmentArm, kMax] <- NA_real_
                 } else {
-                    results$conditionalPower[g, kMax] <- 1 - stats::pnorm(.getQNorm(result) -
-                        standardizedEffect[g] * sqrt(nPlanned[kMax]))
+                    results$conditionalPower[treatmentArm, kMax] <- 1 - stats::pnorm(.getQNorm(result) -
+                        standardizedEffect[treatmentArm] * sqrt(nPlanned[kMax]))
                 }
             }
         }
@@ -1228,7 +1245,7 @@
         sqrt(piTreatments * (1 - piTreatments) + allocationRatioPlanned * piControl * (1 - piControl))) *
         (1 + allocationRatioPlanned) / sqrt(allocationRatioPlanned * sum(nPlanned[(stage + 1):2]))
     adjustment[condError < 1e-12] <- 0
-        
+
     if (length(piTreatments) == 1) {
         piTreatments <- rep(piTreatments, gMax)
         results$.setParameterType("piTreatments", C_PARAM_GENERATED)
@@ -1247,13 +1264,13 @@
 
     ctr <- .getClosedConditionalDunnettTestResults(stageResults = stageResults, design = design, stage = stage)
 
-    for (g in 1:gMax) {
-        if (!is.na(ctr$separatePValues[g, stage])) {
-            results$conditionalPower[g, 2] <- 1 -
+    for (treatmentArm in 1:gMax) {
+        if (!is.na(ctr$separatePValues[treatmentArm, stage])) {
+            results$conditionalPower[treatmentArm, 2] <- 1 -
                 stats::pnorm(.getOneMinusQNorm(min(ctr$conditionalErrorRate[
-                    ctr$indices[, g] == 1,
+                    ctr$indices[, treatmentArm] == 1,
                     stage
-                ], na.rm = TRUE)) - standardizedEffect[g] * sqrt(nPlanned[2]))
+                ], na.rm = TRUE)) - standardizedEffect[treatmentArm] * sqrt(nPlanned[2]))
         }
     }
 
@@ -1312,8 +1329,8 @@
 
     j <- 1
     for (i in seq(along = piTreatmentRange)) {
-        for (g in (1:gMax)) {
-            treatmentArms[j] <- g
+        for (treatmentArm in (1:gMax)) {
+            treatmentArms[j] <- treatmentArm
             effectValues[j] <- piTreatmentRange[i]
 
             if (.isTrialDesignInverseNormal(design)) {
@@ -1323,7 +1340,7 @@
                     allocationRatioPlanned = allocationRatioPlanned,
                     piControl = piControl,
                     piTreatments = piTreatmentRange[i]
-                )$conditionalPower[g, kMax]
+                )$conditionalPower[treatmentArm, kMax]
             } else if (.isTrialDesignFisher(design)) {
                 condPowerValues[j] <- .getConditionalPowerRatesMultiArmFisher(
                     results = results,
@@ -1332,7 +1349,7 @@
                     piControl = piControl,
                     piTreatments = piTreatmentRange[i],
                     iterations = iterations, seed = seed
-                )$conditionalPower[g, kMax]
+                )$conditionalPower[treatmentArm, kMax]
             } else if (.isTrialDesignConditionalDunnett(design)) {
                 condPowerValues[j] <- .getConditionalPowerRatesMultiArmConditionalDunnett(
                     results = results,
@@ -1340,11 +1357,11 @@
                     allocationRatioPlanned = allocationRatioPlanned,
                     piControl = piControl,
                     piTreatments = piTreatmentRange[i]
-                )$conditionalPower[g, 2]
+                )$conditionalPower[treatmentArm, 2]
             }
 
-            likelihoodValues[j] <- stats::dnorm(piTreatmentRange[i], stageResults$overallPiTreatments[g, stage], stdErr[g]) /
-                stats::dnorm(0, 0, stdErr[g])
+            likelihoodValues[j] <- stats::dnorm(piTreatmentRange[i], stageResults$overallPiTreatments[treatmentArm, stage], stdErr[treatmentArm]) /
+                stats::dnorm(0, 0, stdErr[treatmentArm])
             j <- j + 1
         }
     }
