@@ -1,22 +1,22 @@
-#:# 
-#:#  *rpact*
-#:# 
-#:#  This file is part of the R package rpact: 
-#:#  Confirmatory Adaptive Clinical Trial Design and Analysis
-#:# 
-#:#  Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD
-#:#  Licensed under "GNU Lesser General Public License" version 3
-#:#  License text can be found here: https://www.r-project.org/Licenses/LGPL-3
-#:# 
-#:#  RPACT company website: https://www.rpact.com
-#:#  rpact package website: https://www.rpact.org
-#:# 
-#:#  Contact us for information about our services: info@rpact.com
-#:# 
-#:#  File version: $Revision: 4980 $
-#:#  Last changed: $Date: 2021-06-10 11:11:06 +0200 (Do, 10 Jun 2021) $
-#:#  Last changed by: $Author: pahlke $
-#:# 
+## | 
+## |  *rpact*
+## | 
+## |  This file is part of the R package rpact: 
+## |  Confirmatory Adaptive Clinical Trial Design and Analysis
+## | 
+## |  Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD
+## |  Licensed under "GNU Lesser General Public License" version 3
+## |  License text can be found here: https://www.r-project.org/Licenses/LGPL-3
+## | 
+## |  RPACT company website: https://www.rpact.com
+## |  rpact package website: https://www.rpact.org
+## | 
+## |  Contact us for information about our services: info@rpact.com
+## | 
+## |  File version: $Revision: 5855 $
+## |  Last changed: $Date: 2022-02-18 13:23:48 +0100 (Fr, 18 Feb 2022) $
+## |  Last changed by: $Author: pahlke $
+## | 
 
 #' 
 #' @title
@@ -75,9 +75,6 @@
 "_PACKAGE"
 #> [1] "_PACKAGE"
 
-.onLoad <- function(libname, pkgname) {
-}
-
 .onAttach <- function(libname, pkgname) {
 	if (grepl("^\\d\\.\\d\\.\\d\\.\\d{4,4}$", packageVersion("rpact"))) {
 		packageStartupMessage(paste0("rpact developer version ", packageVersion("rpact"), " loaded"))
